Class: SwaggerClient::ClusterControllerApi

Inherits:
Object
  • Object
show all
Defined in:
lib/swagger_client/api/cluster_controller_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ClusterControllerApi

Returns a new instance of ClusterControllerApi.



19
20
21
# File 'lib/swagger_client/api/cluster_controller_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/swagger_client/api/cluster_controller_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_cluster_load_balancers_using_get(application_name, account, cluster_name, type, opts = {}) ⇒ Array<Object>

Retrieve a cluster's loadbalancers

Parameters:

  • application_name

    applicationName

  • account

    account

  • cluster_name

    clusterName

  • type

    type

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_rate_limit_app (String)

    X-RateLimit-App

Returns:

  • (Array<Object>)


30
31
32
33
# File 'lib/swagger_client/api/cluster_controller_api.rb', line 30

def get_cluster_load_balancers_using_get(application_name, , cluster_name, type, opts = {})
  data, _status_code, _headers = get_cluster_load_balancers_using_get_with_http_info(application_name, , cluster_name, type, opts)
  data
end

#get_cluster_load_balancers_using_get_with_http_info(application_name, account, cluster_name, type, opts = {}) ⇒ Array<(Array<Object>, Fixnum, Hash)>

Retrieve a cluster's loadbalancers

Parameters:

  • application_name

    applicationName

  • account

    account

  • cluster_name

    clusterName

  • type

    type

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :x_rate_limit_app (String)

    X-RateLimit-App

Returns:

  • (Array<(Array<Object>, Fixnum, Hash)>)

    Array data, response status code and response headers

    
    
    43
    44
    45
    46
    47
    48
    49
    50
    51
    52
    53
    54
    55
    56
    57
    58
    59
    60
    61
    62
    63
    64
    65
    66
    67
    68
    69
    70
    71
    72
    73
    74
    75
    76
    77
    78
    79
    80
    81
    82
    83
    84
    85
    86
    87
    88
    89
    90
    91
    92
    93
    94
    # File 'lib/swagger_client/api/cluster_controller_api.rb', line 43
    
    def get_cluster_load_balancers_using_get_with_http_info(application_name, , cluster_name, type, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: ClusterControllerApi.get_cluster_load_balancers_using_get ...'
      end
      # verify the required parameter 'application_name' is set
      if @api_client.config.client_side_validation && application_name.nil?
        fail ArgumentError, "Missing the required parameter 'application_name' when calling ClusterControllerApi.get_cluster_load_balancers_using_get"
      end
      # verify the required parameter 'account' is set
      if @api_client.config.client_side_validation && .nil?
        fail ArgumentError, "Missing the required parameter 'account' when calling ClusterControllerApi.get_cluster_load_balancers_using_get"
      end
      # verify the required parameter 'cluster_name' is set
      if @api_client.config.client_side_validation && cluster_name.nil?
        fail ArgumentError, "Missing the required parameter 'cluster_name' when calling ClusterControllerApi.get_cluster_load_balancers_using_get"
      end
      # verify the required parameter 'type' is set
      if @api_client.config.client_side_validation && type.nil?
        fail ArgumentError, "Missing the required parameter 'type' when calling ClusterControllerApi.get_cluster_load_balancers_using_get"
      end
      # resource path
      local_var_path = '/applications/{application}/clusters/{account}/{clusterName}/{type}/loadBalancers'.sub('{' + 'applicationName' + '}', application_name.to_s).sub('{' + 'account' + '}', .to_s).sub('{' + 'clusterName' + '}', cluster_name.to_s).sub('{' + 'type' + '}', type.to_s)
    
      # query parameters
      query_params = {}
    
      # header parameters
      header_params = {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['*/*'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
      header_params[:'X-RateLimit-App'] = opts[:'x_rate_limit_app'] if !opts[:'x_rate_limit_app'].nil?
    
      # form parameters
      form_params = {}
    
      # http body (model)
      post_body = nil
      auth_names = []
      data, status_code, headers = @api_client.call_api(:GET, local_var_path,
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => 'Array<Object>')
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: ClusterControllerApi#get_cluster_load_balancers_using_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    #get_clusters_using_get(application, account, cluster_name, opts = {}) ⇒ Hash<String, Object>

    Retrieve a cluster's details

    Parameters:

    • application

      application

    • account

      account

    • cluster_name

      clusterName

    • opts (Hash) (defaults to: {})

      the optional parameters

    Options Hash (opts):

    • :x_rate_limit_app (String)

      X-RateLimit-App

    Returns:

    • (Hash<String, Object>)
    
    
    102
    103
    104
    105
    # File 'lib/swagger_client/api/cluster_controller_api.rb', line 102
    
    def get_clusters_using_get(application, , cluster_name, opts = {})
      data, _status_code, _headers = get_clusters_using_get_with_http_info(application, , cluster_name, opts)
      data
    end

    #get_clusters_using_get1(application, account, opts = {}) ⇒ Array<Object>

    Retrieve a list of clusters for an account

    Parameters:

    • application

      application

    • account

      account

    • opts (Hash) (defaults to: {})

      the optional parameters

    Options Hash (opts):

    • :x_rate_limit_app (String)

      X-RateLimit-App

    Returns:

    • (Array<Object>)
    
    
    168
    169
    170
    171
    # File 'lib/swagger_client/api/cluster_controller_api.rb', line 168
    
    def get_clusters_using_get1(application, , opts = {})
      data, _status_code, _headers = get_clusters_using_get1_with_http_info(application, , opts)
      data
    end

    #get_clusters_using_get1_with_http_info(application, account, opts = {}) ⇒ Array<(Array<Object>, Fixnum, Hash)>

    Retrieve a list of clusters for an account

    Parameters:

    • application

      application

    • account

      account

    • opts (Hash) (defaults to: {})

      the optional parameters

    Options Hash (opts):

    • :x_rate_limit_app (String)

      X-RateLimit-App

    Returns:

    • (Array<(Array<Object>, Fixnum, Hash)>)

      Array data, response status code and response headers

      
      
      179
      180
      181
      182
      183
      184
      185
      186
      187
      188
      189
      190
      191
      192
      193
      194
      195
      196
      197
      198
      199
      200
      201
      202
      203
      204
      205
      206
      207
      208
      209
      210
      211
      212
      213
      214
      215
      216
      217
      218
      219
      220
      221
      222
      # File 'lib/swagger_client/api/cluster_controller_api.rb', line 179
      
      def get_clusters_using_get1_with_http_info(application, , opts = {})
        if @api_client.config.debugging
          @api_client.config.logger.debug 'Calling API: ClusterControllerApi.get_clusters_using_get1 ...'
        end
        # verify the required parameter 'application' is set
        if @api_client.config.client_side_validation && application.nil?
          fail ArgumentError, "Missing the required parameter 'application' when calling ClusterControllerApi.get_clusters_using_get1"
        end
        # verify the required parameter 'account' is set
        if @api_client.config.client_side_validation && .nil?
          fail ArgumentError, "Missing the required parameter 'account' when calling ClusterControllerApi.get_clusters_using_get1"
        end
        # resource path
        local_var_path = '/applications/{application}/clusters/{account}'.sub('{' + 'application' + '}', application.to_s).sub('{' + 'account' + '}', .to_s)
      
        # query parameters
        query_params = {}
      
        # header parameters
        header_params = {}
        # HTTP header 'Accept' (if needed)
        header_params['Accept'] = @api_client.select_header_accept(['*/*'])
        # HTTP header 'Content-Type'
        header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
        header_params[:'X-RateLimit-App'] = opts[:'x_rate_limit_app'] if !opts[:'x_rate_limit_app'].nil?
      
        # form parameters
        form_params = {}
      
        # http body (model)
        post_body = nil
        auth_names = []
        data, status_code, headers = @api_client.call_api(:GET, local_var_path,
          :header_params => header_params,
          :query_params => query_params,
          :form_params => form_params,
          :body => post_body,
          :auth_names => auth_names,
          :return_type => 'Array<Object>')
        if @api_client.config.debugging
          @api_client.config.logger.debug "API called: ClusterControllerApi#get_clusters_using_get1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
        end
        return data, status_code, headers
      end

      #get_clusters_using_get2(application, opts = {}) ⇒ Hash<String, Object>

      Retrieve a list of cluster names for an application, grouped by account

      Parameters:

      • application

        application

      • opts (Hash) (defaults to: {})

        the optional parameters

      Options Hash (opts):

      • :x_rate_limit_app (String)

        X-RateLimit-App

      Returns:

      • (Hash<String, Object>)
      
      
      228
      229
      230
      231
      # File 'lib/swagger_client/api/cluster_controller_api.rb', line 228
      
      def get_clusters_using_get2(application, opts = {})
        data, _status_code, _headers = get_clusters_using_get2_with_http_info(application, opts)
        data
      end

      #get_clusters_using_get2_with_http_info(application, opts = {}) ⇒ Array<(Hash<String, Object>, Fixnum, Hash)>

      Retrieve a list of cluster names for an application, grouped by account

      Parameters:

      • application

        application

      • opts (Hash) (defaults to: {})

        the optional parameters

      Options Hash (opts):

      • :x_rate_limit_app (String)

        X-RateLimit-App

      Returns:

      • (Array<(Hash<String, Object>, Fixnum, Hash)>)

        Hash<String, Object> data, response status code and response headers

      
      
      238
      239
      240
      241
      242
      243
      244
      245
      246
      247
      248
      249
      250
      251
      252
      253
      254
      255
      256
      257
      258
      259
      260
      261
      262
      263
      264
      265
      266
      267
      268
      269
      270
      271
      272
      273
      274
      275
      276
      277
      # File 'lib/swagger_client/api/cluster_controller_api.rb', line 238
      
      def get_clusters_using_get2_with_http_info(application, opts = {})
        if @api_client.config.debugging
          @api_client.config.logger.debug 'Calling API: ClusterControllerApi.get_clusters_using_get2 ...'
        end
        # verify the required parameter 'application' is set
        if @api_client.config.client_side_validation && application.nil?
          fail ArgumentError, "Missing the required parameter 'application' when calling ClusterControllerApi.get_clusters_using_get2"
        end
        # resource path
        local_var_path = '/applications/{application}/clusters'.sub('{' + 'application' + '}', application.to_s)
      
        # query parameters
        query_params = {}
      
        # header parameters
        header_params = {}
        # HTTP header 'Accept' (if needed)
        header_params['Accept'] = @api_client.select_header_accept(['*/*'])
        # HTTP header 'Content-Type'
        header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
        header_params[:'X-RateLimit-App'] = opts[:'x_rate_limit_app'] if !opts[:'x_rate_limit_app'].nil?
      
        # form parameters
        form_params = {}
      
        # http body (model)
        post_body = nil
        auth_names = []
        data, status_code, headers = @api_client.call_api(:GET, local_var_path,
          :header_params => header_params,
          :query_params => query_params,
          :form_params => form_params,
          :body => post_body,
          :auth_names => auth_names,
          :return_type => 'Hash<String, Object>')
        if @api_client.config.debugging
          @api_client.config.logger.debug "API called: ClusterControllerApi#get_clusters_using_get2\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
        end
        return data, status_code, headers
      end

      #get_clusters_using_get_with_http_info(application, account, cluster_name, opts = {}) ⇒ Array<(Hash<String, Object>, Fixnum, Hash)>

      Retrieve a cluster's details

      Parameters:

      • application

        application

      • account

        account

      • cluster_name

        clusterName

      • opts (Hash) (defaults to: {})

        the optional parameters

      Options Hash (opts):

      • :x_rate_limit_app (String)

        X-RateLimit-App

      Returns:

      • (Array<(Hash<String, Object>, Fixnum, Hash)>)

        Hash<String, Object> data, response status code and response headers

      
      
      114
      115
      116
      117
      118
      119
      120
      121
      122
      123
      124
      125
      126
      127
      128
      129
      130
      131
      132
      133
      134
      135
      136
      137
      138
      139
      140
      141
      142
      143
      144
      145
      146
      147
      148
      149
      150
      151
      152
      153
      154
      155
      156
      157
      158
      159
      160
      161
      # File 'lib/swagger_client/api/cluster_controller_api.rb', line 114
      
      def get_clusters_using_get_with_http_info(application, , cluster_name, opts = {})
        if @api_client.config.debugging
          @api_client.config.logger.debug 'Calling API: ClusterControllerApi.get_clusters_using_get ...'
        end
        # verify the required parameter 'application' is set
        if @api_client.config.client_side_validation && application.nil?
          fail ArgumentError, "Missing the required parameter 'application' when calling ClusterControllerApi.get_clusters_using_get"
        end
        # verify the required parameter 'account' is set
        if @api_client.config.client_side_validation && .nil?
          fail ArgumentError, "Missing the required parameter 'account' when calling ClusterControllerApi.get_clusters_using_get"
        end
        # verify the required parameter 'cluster_name' is set
        if @api_client.config.client_side_validation && cluster_name.nil?
          fail ArgumentError, "Missing the required parameter 'cluster_name' when calling ClusterControllerApi.get_clusters_using_get"
        end
        # resource path
        local_var_path = '/applications/{application}/clusters/{account}/{clusterName}'.sub('{' + 'application' + '}', application.to_s).sub('{' + 'account' + '}', .to_s).sub('{' + 'clusterName' + '}', cluster_name.to_s)
      
        # query parameters
        query_params = {}
      
        # header parameters
        header_params = {}
        # HTTP header 'Accept' (if needed)
        header_params['Accept'] = @api_client.select_header_accept(['*/*'])
        # HTTP header 'Content-Type'
        header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
        header_params[:'X-RateLimit-App'] = opts[:'x_rate_limit_app'] if !opts[:'x_rate_limit_app'].nil?
      
        # form parameters
        form_params = {}
      
        # http body (model)
        post_body = nil
        auth_names = []
        data, status_code, headers = @api_client.call_api(:GET, local_var_path,
          :header_params => header_params,
          :query_params => query_params,
          :form_params => form_params,
          :body => post_body,
          :auth_names => auth_names,
          :return_type => 'Hash<String, Object>')
        if @api_client.config.debugging
          @api_client.config.logger.debug "API called: ClusterControllerApi#get_clusters_using_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
        end
        return data, status_code, headers
      end

      #get_scaling_activities_using_get(application, account, cluster_name, server_group_name, opts = {}) ⇒ Array<Object>

      Retrieve a list of scaling activities for a server group

      Parameters:

      • application

        application

      • account

        account

      • cluster_name

        clusterName

      • server_group_name

        serverGroupName

      • opts (Hash) (defaults to: {})

        the optional parameters

      Options Hash (opts):

      • :provider (String)

        provider (default to aws)

      • :region (String)

        region

      • :x_rate_limit_app (String)

        X-RateLimit-App

      Returns:

      • (Array<Object>)
      
      
      288
      289
      290
      291
      # File 'lib/swagger_client/api/cluster_controller_api.rb', line 288
      
      def get_scaling_activities_using_get(application, , cluster_name, server_group_name, opts = {})
        data, _status_code, _headers = get_scaling_activities_using_get_with_http_info(application, , cluster_name, server_group_name, opts)
        data
      end

      #get_scaling_activities_using_get_with_http_info(application, account, cluster_name, server_group_name, opts = {}) ⇒ Array<(Array<Object>, Fixnum, Hash)>

      Retrieve a list of scaling activities for a server group

      Parameters:

      • application

        application

      • account

        account

      • cluster_name

        clusterName

      • server_group_name

        serverGroupName

      • opts (Hash) (defaults to: {})

        the optional parameters

      Options Hash (opts):

      • :provider (String)

        provider

      • :region (String)

        region

      • :x_rate_limit_app (String)

        X-RateLimit-App

      Returns:

      • (Array<(Array<Object>, Fixnum, Hash)>)

        Array data, response status code and response headers

        
        
        303
        304
        305
        306
        307
        308
        309
        310
        311
        312
        313
        314
        315
        316
        317
        318
        319
        320
        321
        322
        323
        324
        325
        326
        327
        328
        329
        330
        331
        332
        333
        334
        335
        336
        337
        338
        339
        340
        341
        342
        343
        344
        345
        346
        347
        348
        349
        350
        351
        352
        353
        354
        355
        356
        # File 'lib/swagger_client/api/cluster_controller_api.rb', line 303
        
        def get_scaling_activities_using_get_with_http_info(application, , cluster_name, server_group_name, opts = {})
          if @api_client.config.debugging
            @api_client.config.logger.debug 'Calling API: ClusterControllerApi.get_scaling_activities_using_get ...'
          end
          # verify the required parameter 'application' is set
          if @api_client.config.client_side_validation && application.nil?
            fail ArgumentError, "Missing the required parameter 'application' when calling ClusterControllerApi.get_scaling_activities_using_get"
          end
          # verify the required parameter 'account' is set
          if @api_client.config.client_side_validation && .nil?
            fail ArgumentError, "Missing the required parameter 'account' when calling ClusterControllerApi.get_scaling_activities_using_get"
          end
          # verify the required parameter 'cluster_name' is set
          if @api_client.config.client_side_validation && cluster_name.nil?
            fail ArgumentError, "Missing the required parameter 'cluster_name' when calling ClusterControllerApi.get_scaling_activities_using_get"
          end
          # verify the required parameter 'server_group_name' is set
          if @api_client.config.client_side_validation && server_group_name.nil?
            fail ArgumentError, "Missing the required parameter 'server_group_name' when calling ClusterControllerApi.get_scaling_activities_using_get"
          end
          # resource path
          local_var_path = '/applications/{application}/clusters/{account}/{clusterName}/serverGroups/{serverGroupName}/scalingActivities'.sub('{' + 'application' + '}', application.to_s).sub('{' + 'account' + '}', .to_s).sub('{' + 'clusterName' + '}', cluster_name.to_s).sub('{' + 'serverGroupName' + '}', server_group_name.to_s)
        
          # query parameters
          query_params = {}
          query_params[:'provider'] = opts[:'provider'] if !opts[:'provider'].nil?
          query_params[:'region'] = opts[:'region'] if !opts[:'region'].nil?
        
          # header parameters
          header_params = {}
          # HTTP header 'Accept' (if needed)
          header_params['Accept'] = @api_client.select_header_accept(['*/*'])
          # HTTP header 'Content-Type'
          header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
          header_params[:'X-RateLimit-App'] = opts[:'x_rate_limit_app'] if !opts[:'x_rate_limit_app'].nil?
        
          # form parameters
          form_params = {}
        
          # http body (model)
          post_body = nil
          auth_names = []
          data, status_code, headers = @api_client.call_api(:GET, local_var_path,
            :header_params => header_params,
            :query_params => query_params,
            :form_params => form_params,
            :body => post_body,
            :auth_names => auth_names,
            :return_type => 'Array<Object>')
          if @api_client.config.debugging
            @api_client.config.logger.debug "API called: ClusterControllerApi#get_scaling_activities_using_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
          end
          return data, status_code, headers
        end

        #get_server_groups_using_get(application, account, cluster_name, server_group_name, opts = {}) ⇒ Array<Object>

        Retrieve a server group's details

        Parameters:

        • application

          application

        • account

          account

        • cluster_name

          clusterName

        • server_group_name

          serverGroupName

        • opts (Hash) (defaults to: {})

          the optional parameters

        Options Hash (opts):

        • :x_rate_limit_app (String)

          X-RateLimit-App

        Returns:

        • (Array<Object>)
        
        
        365
        366
        367
        368
        # File 'lib/swagger_client/api/cluster_controller_api.rb', line 365
        
        def get_server_groups_using_get(application, , cluster_name, server_group_name, opts = {})
          data, _status_code, _headers = get_server_groups_using_get_with_http_info(application, , cluster_name, server_group_name, opts)
          data
        end

        #get_server_groups_using_get1(application, account, cluster_name, opts = {}) ⇒ Array<Object>

        Retrieve a list of server groups for a cluster

        Parameters:

        • application

          application

        • account

          account

        • cluster_name

          clusterName

        • opts (Hash) (defaults to: {})

          the optional parameters

        Options Hash (opts):

        • :x_rate_limit_app (String)

          X-RateLimit-App

        Returns:

        • (Array<Object>)
        
        
        437
        438
        439
        440
        # File 'lib/swagger_client/api/cluster_controller_api.rb', line 437
        
        def get_server_groups_using_get1(application, , cluster_name, opts = {})
          data, _status_code, _headers = get_server_groups_using_get1_with_http_info(application, , cluster_name, opts)
          data
        end

        #get_server_groups_using_get1_with_http_info(application, account, cluster_name, opts = {}) ⇒ Array<(Array<Object>, Fixnum, Hash)>

        Retrieve a list of server groups for a cluster

        Parameters:

        • application

          application

        • account

          account

        • cluster_name

          clusterName

        • opts (Hash) (defaults to: {})

          the optional parameters

        Options Hash (opts):

        • :x_rate_limit_app (String)

          X-RateLimit-App

        Returns:

        • (Array<(Array<Object>, Fixnum, Hash)>)

          Array data, response status code and response headers

          
          
          449
          450
          451
          452
          453
          454
          455
          456
          457
          458
          459
          460
          461
          462
          463
          464
          465
          466
          467
          468
          469
          470
          471
          472
          473
          474
          475
          476
          477
          478
          479
          480
          481
          482
          483
          484
          485
          486
          487
          488
          489
          490
          491
          492
          493
          494
          495
          496
          # File 'lib/swagger_client/api/cluster_controller_api.rb', line 449
          
          def get_server_groups_using_get1_with_http_info(application, , cluster_name, opts = {})
            if @api_client.config.debugging
              @api_client.config.logger.debug 'Calling API: ClusterControllerApi.get_server_groups_using_get1 ...'
            end
            # verify the required parameter 'application' is set
            if @api_client.config.client_side_validation && application.nil?
              fail ArgumentError, "Missing the required parameter 'application' when calling ClusterControllerApi.get_server_groups_using_get1"
            end
            # verify the required parameter 'account' is set
            if @api_client.config.client_side_validation && .nil?
              fail ArgumentError, "Missing the required parameter 'account' when calling ClusterControllerApi.get_server_groups_using_get1"
            end
            # verify the required parameter 'cluster_name' is set
            if @api_client.config.client_side_validation && cluster_name.nil?
              fail ArgumentError, "Missing the required parameter 'cluster_name' when calling ClusterControllerApi.get_server_groups_using_get1"
            end
            # resource path
            local_var_path = '/applications/{application}/clusters/{account}/{clusterName}/serverGroups'.sub('{' + 'application' + '}', application.to_s).sub('{' + 'account' + '}', .to_s).sub('{' + 'clusterName' + '}', cluster_name.to_s)
          
            # query parameters
            query_params = {}
          
            # header parameters
            header_params = {}
            # HTTP header 'Accept' (if needed)
            header_params['Accept'] = @api_client.select_header_accept(['*/*'])
            # HTTP header 'Content-Type'
            header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
            header_params[:'X-RateLimit-App'] = opts[:'x_rate_limit_app'] if !opts[:'x_rate_limit_app'].nil?
          
            # form parameters
            form_params = {}
          
            # http body (model)
            post_body = nil
            auth_names = []
            data, status_code, headers = @api_client.call_api(:GET, local_var_path,
              :header_params => header_params,
              :query_params => query_params,
              :form_params => form_params,
              :body => post_body,
              :auth_names => auth_names,
              :return_type => 'Array<Object>')
            if @api_client.config.debugging
              @api_client.config.logger.debug "API called: ClusterControllerApi#get_server_groups_using_get1\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
            end
            return data, status_code, headers
          end

          #get_server_groups_using_get_with_http_info(application, account, cluster_name, server_group_name, opts = {}) ⇒ Array<(Array<Object>, Fixnum, Hash)>

          Retrieve a server group's details

          Parameters:

          • application

            application

          • account

            account

          • cluster_name

            clusterName

          • server_group_name

            serverGroupName

          • opts (Hash) (defaults to: {})

            the optional parameters

          Options Hash (opts):

          • :x_rate_limit_app (String)

            X-RateLimit-App

          Returns:

          • (Array<(Array<Object>, Fixnum, Hash)>)

            Array data, response status code and response headers

            
            
            378
            379
            380
            381
            382
            383
            384
            385
            386
            387
            388
            389
            390
            391
            392
            393
            394
            395
            396
            397
            398
            399
            400
            401
            402
            403
            404
            405
            406
            407
            408
            409
            410
            411
            412
            413
            414
            415
            416
            417
            418
            419
            420
            421
            422
            423
            424
            425
            426
            427
            428
            429
            # File 'lib/swagger_client/api/cluster_controller_api.rb', line 378
            
            def get_server_groups_using_get_with_http_info(application, , cluster_name, server_group_name, opts = {})
              if @api_client.config.debugging
                @api_client.config.logger.debug 'Calling API: ClusterControllerApi.get_server_groups_using_get ...'
              end
              # verify the required parameter 'application' is set
              if @api_client.config.client_side_validation && application.nil?
                fail ArgumentError, "Missing the required parameter 'application' when calling ClusterControllerApi.get_server_groups_using_get"
              end
              # verify the required parameter 'account' is set
              if @api_client.config.client_side_validation && .nil?
                fail ArgumentError, "Missing the required parameter 'account' when calling ClusterControllerApi.get_server_groups_using_get"
              end
              # verify the required parameter 'cluster_name' is set
              if @api_client.config.client_side_validation && cluster_name.nil?
                fail ArgumentError, "Missing the required parameter 'cluster_name' when calling ClusterControllerApi.get_server_groups_using_get"
              end
              # verify the required parameter 'server_group_name' is set
              if @api_client.config.client_side_validation && server_group_name.nil?
                fail ArgumentError, "Missing the required parameter 'server_group_name' when calling ClusterControllerApi.get_server_groups_using_get"
              end
              # resource path
              local_var_path = '/applications/{application}/clusters/{account}/{clusterName}/serverGroups/{serverGroupName}'.sub('{' + 'application' + '}', application.to_s).sub('{' + 'account' + '}', .to_s).sub('{' + 'clusterName' + '}', cluster_name.to_s).sub('{' + 'serverGroupName' + '}', server_group_name.to_s)
            
              # query parameters
              query_params = {}
            
              # header parameters
              header_params = {}
              # HTTP header 'Accept' (if needed)
              header_params['Accept'] = @api_client.select_header_accept(['*/*'])
              # HTTP header 'Content-Type'
              header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
              header_params[:'X-RateLimit-App'] = opts[:'x_rate_limit_app'] if !opts[:'x_rate_limit_app'].nil?
            
              # form parameters
              form_params = {}
            
              # http body (model)
              post_body = nil
              auth_names = []
              data, status_code, headers = @api_client.call_api(:GET, local_var_path,
                :header_params => header_params,
                :query_params => query_params,
                :form_params => form_params,
                :body => post_body,
                :auth_names => auth_names,
                :return_type => 'Array<Object>')
              if @api_client.config.debugging
                @api_client.config.logger.debug "API called: ClusterControllerApi#get_server_groups_using_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
              end
              return data, status_code, headers
            end

            #get_target_server_group_using_get(application, account, cluster_name, cloud_provider, scope, target, opts = {}) ⇒ Hash<String, Object>

            Retrieve a server group that matches a target coordinate (e.g., newest, ancestor) relative to a cluster scope is either a zone or a region

            Parameters:

            • application

              application

            • account

              account

            • cluster_name

              clusterName

            • cloud_provider

              cloudProvider

            • scope

              scope

            • target

              target

            • opts (Hash) (defaults to: {})

              the optional parameters

            Options Hash (opts):

            • :only_enabled (BOOLEAN)

              onlyEnabled

            • :validate_oldest (BOOLEAN)

              validateOldest

            • :x_rate_limit_app (String)

              X-RateLimit-App

            Returns:

            • (Hash<String, Object>)
            
            
            510
            511
            512
            513
            # File 'lib/swagger_client/api/cluster_controller_api.rb', line 510
            
            def get_target_server_group_using_get(application, , cluster_name, cloud_provider, scope, target, opts = {})
              data, _status_code, _headers = get_target_server_group_using_get_with_http_info(application, , cluster_name, cloud_provider, scope, target, opts)
              data
            end

            #get_target_server_group_using_get_with_http_info(application, account, cluster_name, cloud_provider, scope, target, opts = {}) ⇒ Array<(Hash<String, Object>, Fixnum, Hash)>

            Retrieve a server group that matches a target coordinate (e.g., newest, ancestor) relative to a cluster `scope` is either a zone or a region

            Parameters:

            • application

              application

            • account

              account

            • cluster_name

              clusterName

            • cloud_provider

              cloudProvider

            • scope

              scope

            • target

              target

            • opts (Hash) (defaults to: {})

              the optional parameters

            Options Hash (opts):

            • :only_enabled (BOOLEAN)

              onlyEnabled

            • :validate_oldest (BOOLEAN)

              validateOldest

            • :x_rate_limit_app (String)

              X-RateLimit-App

            Returns:

            • (Array<(Hash<String, Object>, Fixnum, Hash)>)

              Hash<String, Object> data, response status code and response headers

            
            
            528
            529
            530
            531
            532
            533
            534
            535
            536
            537
            538
            539
            540
            541
            542
            543
            544
            545
            546
            547
            548
            549
            550
            551
            552
            553
            554
            555
            556
            557
            558
            559
            560
            561
            562
            563
            564
            565
            566
            567
            568
            569
            570
            571
            572
            573
            574
            575
            576
            577
            578
            579
            580
            581
            582
            583
            584
            585
            586
            587
            588
            589
            # File 'lib/swagger_client/api/cluster_controller_api.rb', line 528
            
            def get_target_server_group_using_get_with_http_info(application, , cluster_name, cloud_provider, scope, target, opts = {})
              if @api_client.config.debugging
                @api_client.config.logger.debug 'Calling API: ClusterControllerApi.get_target_server_group_using_get ...'
              end
              # verify the required parameter 'application' is set
              if @api_client.config.client_side_validation && application.nil?
                fail ArgumentError, "Missing the required parameter 'application' when calling ClusterControllerApi.get_target_server_group_using_get"
              end
              # verify the required parameter 'account' is set
              if @api_client.config.client_side_validation && .nil?
                fail ArgumentError, "Missing the required parameter 'account' when calling ClusterControllerApi.get_target_server_group_using_get"
              end
              # verify the required parameter 'cluster_name' is set
              if @api_client.config.client_side_validation && cluster_name.nil?
                fail ArgumentError, "Missing the required parameter 'cluster_name' when calling ClusterControllerApi.get_target_server_group_using_get"
              end
              # verify the required parameter 'cloud_provider' is set
              if @api_client.config.client_side_validation && cloud_provider.nil?
                fail ArgumentError, "Missing the required parameter 'cloud_provider' when calling ClusterControllerApi.get_target_server_group_using_get"
              end
              # verify the required parameter 'scope' is set
              if @api_client.config.client_side_validation && scope.nil?
                fail ArgumentError, "Missing the required parameter 'scope' when calling ClusterControllerApi.get_target_server_group_using_get"
              end
              # verify the required parameter 'target' is set
              if @api_client.config.client_side_validation && target.nil?
                fail ArgumentError, "Missing the required parameter 'target' when calling ClusterControllerApi.get_target_server_group_using_get"
              end
              # resource path
              local_var_path = '/applications/{application}/clusters/{account}/{clusterName}/{cloudProvider}/{scope}/serverGroups/target/{target}'.sub('{' + 'application' + '}', application.to_s).sub('{' + 'account' + '}', .to_s).sub('{' + 'clusterName' + '}', cluster_name.to_s).sub('{' + 'cloudProvider' + '}', cloud_provider.to_s).sub('{' + 'scope' + '}', scope.to_s).sub('{' + 'target' + '}', target.to_s)
            
              # query parameters
              query_params = {}
              query_params[:'onlyEnabled'] = opts[:'only_enabled'] if !opts[:'only_enabled'].nil?
              query_params[:'validateOldest'] = opts[:'validate_oldest'] if !opts[:'validate_oldest'].nil?
            
              # header parameters
              header_params = {}
              # HTTP header 'Accept' (if needed)
              header_params['Accept'] = @api_client.select_header_accept(['*/*'])
              # HTTP header 'Content-Type'
              header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])
              header_params[:'X-RateLimit-App'] = opts[:'x_rate_limit_app'] if !opts[:'x_rate_limit_app'].nil?
            
              # form parameters
              form_params = {}
            
              # http body (model)
              post_body = nil
              auth_names = []
              data, status_code, headers = @api_client.call_api(:GET, local_var_path,
                :header_params => header_params,
                :query_params => query_params,
                :form_params => form_params,
                :body => post_body,
                :auth_names => auth_names,
                :return_type => 'Hash<String, Object>')
              if @api_client.config.debugging
                @api_client.config.logger.debug "API called: ClusterControllerApi#get_target_server_group_using_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
              end
              return data, status_code, headers
            end